@@ -22,8 +22,6 @@ using Gtk;
 using Gdk;
 using Mono.Unix;
 using System.Text;
-using System.Reflection;
-using System.Runtime.InteropServices;
 
 namespace gbrainy.Clients.Classical
 {
@@ -40,7 +38,9 @@ namespace gbrainy.Clients.Classical
 				"Anna Barber\u00e0 Mar\u00e9",
 				"Carme Cabal Sard\u00e0",
 				"Jordi Mas i Hernandez",
-				"Openclipart.org"
+				"Felipe Menegaz",
+				"Openclipart.org",
+
 			};
 
 			string [] documenters = new string [] {
@@ -82,7 +82,10 @@ namespace gbrainy.Clients.Classical
 		{
 			try {
 				return new Pixbuf (System.Reflection.Assembly.GetEntryAssembly (), resource);
-			} catch {
+			} 
+			catch (Exception e)
+			{
+				Console.WriteLine ("AboutDialog.LoadFromAssembly. Could not load resource {0}. Error {1}", resource, e);
 				return null;
 			}
 		}
