@@ -20,10 +20,8 @@
 using System;
 using Gtk;
 using Mono.Unix;
-using System.Collections;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Views;
 
 namespace gbrainy.Clients.Classical
@@ -45,9 +43,17 @@ namespace gbrainy.Clients.Classical
 			string label;
 
 			label = Catalog.GetString ("The graph below shows the player's game score evolution. ");
-			label +=  Catalog.GetPluralString ("You need more than one game recorded to see the score evolution.",
-				"It is built using the results of {0} last recorded games.", 
-				history.Games.Count < 2 ? 1 : 2);
+
+			if (history.Games.Count < 2)
+			{
+				label += Catalog.GetString ("You need more than one game session recorded to see the score evolution.");
+			}
+			else 
+			{
+				label +=  Catalog.GetPluralString ("It is built using the results of {0} recorded game session.",
+					"It is built using the results of the last {0} recorded game sessions.",
+					history.Games.Count);
+			}
 
 			label_playerhistory.Text = String.Format (label, history.Games.Count);
 
@@ -56,10 +62,10 @@ namespace gbrainy.Clients.Classical
 			drawing_area.Visible = true;
 
 	 		checkbutton_total.Label = Catalog.GetString ("Total");
-	 		checkbutton_logic.Label = Game.GetGameTypeDescription (Game.Types.LogicPuzzle);
-	 		checkbutton_calculation.Label = Game.GetGameTypeDescription (Game.Types.MathTrainer);
-	 		checkbutton_memory.Label = Game.GetGameTypeDescription (Game.Types.MemoryTrainer);
-	 		checkbutton_verbal.Label = Game.GetGameTypeDescription (Game.Types.VerbalAnalogy);
+	 		checkbutton_logic.Label = GameTypesDescription.GetLocalized (GameTypes.LogicPuzzle);
+	 		checkbutton_calculation.Label = GameTypesDescription.GetLocalized (GameTypes.MathTrainer);
+	 		checkbutton_memory.Label = GameTypesDescription.GetLocalized (GameTypes.MemoryTrainer);
+	 		checkbutton_verbal.Label = GameTypesDescription.GetLocalized (GameTypes.VerbalAnalogy);
 
 	 		checkbutton_total.Active = checkbutton_memory.Active = checkbutton_logic.Active = checkbutton_calculation.Active = checkbutton_verbal.Active = true;
 		}
@@ -94,7 +100,7 @@ namespace gbrainy.Clients.Classical
 			drawing_area.QueueDraw ();
 		}
 
-		public class CairoPreview : DrawingArea 
+		public class CairoPreview : DrawingArea
 		{
 			PlayerHistoryView view;
 
@@ -106,7 +112,7 @@ namespace gbrainy.Clients.Classical
 			public PlayerHistoryView View {
 				get { return view; }
 			}
-	
+
 			protected override bool OnExposeEvent (Gdk.EventExpose args)
 			{
 				if(!IsRealized)
@@ -128,7 +134,7 @@ namespace gbrainy.Clients.Classical
 				if (nh < h) {
 					y = (h - nh) / 2;
 				}
-	
+
 				cr.Translate (x, y);
 				cr.Scale (nw, nh);
 
@@ -138,6 +144,6 @@ namespace gbrainy.Clients.Classical
 				((IDisposable)cr).Dispose();
 	   			return base.OnExposeEvent(args);
 			}
-		}	
+		}
 	}
 }
