@@ -20,7 +20,6 @@
 using System;
 using Gtk;
 using Mono.Unix;
-using System.Collections;
 
 using gbrainy.Core.Main;
 
@@ -47,35 +46,44 @@ namespace gbrainy.Clients.Classical
 			maxstoredspinbutton.Value = Preferences.GetIntValue (Preferences.MaxStoredGamesKey);
 			minplayedspinbutton.Value = Preferences.GetIntValue (Preferences.MinPlayedGamesKey);
 			colorblindcheckbutton.Active = Preferences.GetBoolValue (Preferences.ColorBlindKey);
-		
-			switch ((Game.Difficulty) Preferences.GetIntValue (Preferences.DifficultyKey)) {
-			case Game.Difficulty.Easy:
+
+			switch ((GameDifficulty) Preferences.GetIntValue (Preferences.DifficultyKey)) {
+			case GameDifficulty.Easy:
 				rb_easy.Active = rb_easy.HasFocus = true;
-				break;		
-			case Game.Difficulty.Medium:
+				break;
+			case GameDifficulty.Medium:
 				rb_medium.Active = rb_medium.HasFocus = true;
 				break;
-			case Game.Difficulty.Master:
+			case GameDifficulty.Master:
 				rb_master.Active = rb_master.HasFocus = true;
 				break;
 			}
 		}
 
-		private Game.Difficulty Difficulty {
+		private GameDifficulty Difficulty {
 			get {
 				if (rb_easy.Active)
-					return Game.Difficulty.Easy;
+					return GameDifficulty.Easy;
 
 				if (rb_master.Active)
-					return Game.Difficulty.Master;
+					return GameDifficulty.Master;
 
-				return Game.Difficulty.Medium;			
+				return GameDifficulty.Medium;
 			}
 		}
 
 		private void OnCleanHistory (object sender, EventArgs args)
 		{
-			history.Clean ();
+			if (ResponseType.Ok == HigMessageDialog.RunHigConfirmation (
+				this,
+				Gtk.DialogFlags.DestroyWithParent,
+				Gtk.MessageType.Warning,
+				Catalog.GetString ("You are about to delete the player's game session history."),
+				Catalog.GetString ("If you proceed, you will lose the history of the previous game sessions. Do you want to continue?"),
+				Catalog.GetString ("_Delete")))
+			{
+				history.Clean ();
+			}
 		}
 
 		private void OnOK (object sender, EventArgs args)
