@@ -20,13 +20,11 @@
 using System;
 using Cairo;
 using Gtk;
-using Gnome;
 using Mono.Unix;
 using System.Diagnostics;
 using Gdk;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Platform;
 
 #if MONO_ADDINS
@@ -34,9 +32,16 @@ using Mono.Addins;
 using Mono.Addins.Setup;
 #endif
 
+#if GNOME
+using Gnome;
+#endif
+
 namespace gbrainy.Clients.Classical
 {
-	public class GtkClient: Program
+	public class GtkClient
+#if GNOME
+		: Program
+#endif
 	{
 		[GtkBeans.Builder.Object("gbrainy")] Gtk.Window app_window;
 		[GtkBeans.Builder.Object] Gtk.CheckMenuItem toolbar_menuitem;
@@ -70,25 +75,58 @@ namespace gbrainy.Clients.Classical
 		bool margins = false;
 		double offset_x, offset_y;
 		int drawing_square;
+		GameSession.Types initial_session;
 
-		public GtkClient (string [] args, params object [] props)
-		: base ("gbrainy", Defines.VERSION, Modules.UI,  args, props)
+		public GtkClient ()
+#if GNOME
+		: base ("gbrainy", Defines.VERSION, Modules.UI, new string [0])
+#endif
 		{
-			bool show_toolbar;
-
 			Catalog.Init ("gbrainy", Defines.GNOME_LOCALE_DIR);
 			Unix.FixLocaleInfo ();
+		}
+
+		public GameSession Session {
+			get { return session; }
+		}
+
+		public GameSession.Types InitialSessionType {
+			get { return initial_session; }
+			set { initial_session = value; }
+		}
+
+		public void Initialize ()
+		{
+			session = new GameSession ();
+			GameManagerPreload (session.GameManager);
+			Console.WriteLine (session.GameManager.GetGamesSummary ());
+
+			session.GameManager.ColorBlind = Preferences.GetBoolValue (Preferences.ColorBlindKey);
+			session.DrawRequest += SessionDrawRequest;
+			session.UpdateUIElement += SessionUpdateUIElement;
+			session.SynchronizingObject = new GtkSynchronize ();
+			session.Difficulty = (GameDifficulty) Preferences.GetIntValue (Preferences.DifficultyKey);
+
+			BuildUI ();
+		}
+
+		public static void GameManagerPreload (GameManager gm)
+		{
+			gm.LoadAssemblyGames (Defines.GAME_ASSEMBLY);
+			gm.LoadVerbalAnalogies (System.IO.Path.Combine (Defines.DATA_DIR, Defines.VERBAL_ANALOGIES));
+			gm.LoadGamesFromXml (System.IO.Path.Combine (Defines.DATA_DIR, Defines.GAMES_FILE));
+			gm.LoadPlugins ();
+		}
+
+		void BuildUI ()
+		{
+			bool show_toolbar;
 
 			GtkBeans.Builder builder = new GtkBeans.Builder ("gbrainy.ui");
 			builder.Autoconnect (this);
 
 			BuildToolBar ();
-			session = new GameSession ();
-			session.DrawRequest += SessionDrawRequest;
-			session.UpdateUIElement += SessionUpdateUIElement;
-			session.SynchronizingObject = new GtkSynchronize ();
 
-			session.Difficulty = (Game.Difficulty) Preferences.GetIntValue (Preferences.DifficultyKey);
 			drawing_area = new DrawingArea ();
 			drawing_area.ExposeEvent += OnDrawingAreaExposeEvent;
 			GameSensitiveUI ();
@@ -110,10 +148,10 @@ namespace gbrainy.Clients.Classical
 			solution_vbox.Add (solution_label);
 
 			EventBox eb = new EventBox (); // Provides a window for drawing area windowless widget
-			
+
 			eb.Events = Gdk.EventMask.PointerMotionMask;
 			drawing_vbox.Add (eb);
-	
+
 			eb.Add (drawing_area);
 
 			eb.MotionNotifyEvent += OnMouseMotionEvent;
@@ -140,6 +178,12 @@ namespace gbrainy.Clients.Classical
 			ActiveInputControls (false);
 		}
 
+		public void ProcessDefaults ()
+		{
+			if (InitialSessionType != GameSession.Types.None)
+				OnNewGame (InitialSessionType);
+		}
+
 		// Gamesession has requested a question refresh
 		public void SessionUpdateUIElement (object o, UpdateUIStateEventArgs args)
 		{
@@ -172,9 +216,9 @@ namespace gbrainy.Clients.Classical
 			Cairo.Context cc = Gdk.CairoHelper.Create (args.Window);
 			CairoContextEx cr = new CairoContextEx (cc.Handle, drawing_area);
 
-			// We want a square drawing area for the puzzles then the figures are shown as designed. 
+			// We want a square drawing area for the puzzles then the figures are shown as designed.
 			// For example, squares are squares. This also makes sure that proportions are kept when resizing
-			drawing_square = Math.Min (w, h);	
+			drawing_square = Math.Min (w, h);
 
 			if (drawing_square < w)
 				offset_x = (w - drawing_square) / 2;
@@ -193,7 +237,7 @@ namespace gbrainy.Clients.Classical
 			((IDisposable)cc).Dispose();
 			((IDisposable)cr).Dispose();
 		}
-		
+
 		void OnMouseMotionEvent (object o, MotionNotifyEventArgs ev_args)
 		{
 			SendMouseEvent (ev_args.Event.X, ev_args.Event.Y, MouseEventType.Move);
@@ -214,7 +258,7 @@ namespace gbrainy.Clients.Classical
 			x = ev_x - offset_x;
 			y = ev_y - offset_y;
 
-			if (x < 0 || y < 0 || x > drawing_square || y > drawing_square) 
+			if (x < 0 || y < 0 || x > drawing_square || y > drawing_square)
 				return;
 
 			x =  x / drawing_square;
@@ -228,31 +272,40 @@ namespace gbrainy.Clients.Classical
 			statusbar.Push (0, session.StatusText);
 		}
 
+		// These are UI elements dependent of the game status
 		public void ActiveInputControls (bool active)
 		{
-			bool answer, entry, next, tip;
+			bool answer, entry, next, tip, can_pause;
 
-			answer = entry = next = tip = active;
+			can_pause = answer = entry = next = tip = active;
 
 			if (active == true && session.CurrentGame != null && session.CurrentGame.ButtonsActive == true && String.IsNullOrEmpty (session.CurrentGame.Tip ) == false)
 				tip = true;
 			else
 				tip = false;
-	
+
 			switch (session.Status) {
 			case GameSession.SessionStatus.NotPlaying:
 			case GameSession.SessionStatus.Finished:
 				answer = false;
-				entry =  false;
+				entry = false;
 				next = false;
 				tip = false;
+				can_pause = false;
 				break;
 			case GameSession.SessionStatus.Playing:
+				if (session.CurrentGame != null) {
+					can_pause = session.CurrentGame.ButtonsActive;
+				}
+				else {
+					can_pause = true;
+				}
 				break;
 			case GameSession.SessionStatus.Answered:
 				answer = false;
-				entry =  false;
+				entry = false;
 				tip = false;
+				can_pause = false;
 				break;
 			}
 
@@ -260,6 +313,7 @@ namespace gbrainy.Clients.Classical
 			answer_entry.Sensitive = entry;
 			next_button.Sensitive = next;
 			tip_button.Sensitive = tip;
+			pause_menuitem.Sensitive = pause_tbbutton.Sensitive = can_pause;
 
 			if (entry == true)
 				answer_entry.GrabFocus ();
@@ -282,7 +336,7 @@ namespace gbrainy.Clients.Classical
 		}
 
 		void UpdateSolution (string solution)
-		{		
+		{
 			solution_label.Text = solution;
 		}
 
@@ -344,43 +398,44 @@ namespace gbrainy.Clients.Classical
 			toolbar.Insert (finish_tbbutton, -1);
 		}
 
-		void GameSensitiveUI () 
+		// These are UI elements independent of the game status, set only when the game starts / ends
+		void GameSensitiveUI ()
 		{
 			//Toolbar buttons and menu items that are sensitive when the user is playing
 			bool playing;
-			Game.Types available;
+			GameTypes available;
 
 			playing = (session.Status == GameSession.SessionStatus.Playing);
-			finish_tbbutton.Sensitive = pause_tbbutton.Sensitive = playing;
+			finish_tbbutton.Sensitive = playing;
 
 			available = session.AvailableGames;
 
-			if (playing == false && ((available & Game.Types.LogicPuzzle) == Game.Types.LogicPuzzle))
+			if (playing == false && ((available & GameTypes.LogicPuzzle) == GameTypes.LogicPuzzle))
 				logic_menuitem.Sensitive = logic_tbbutton.Sensitive = true;
 			else
 				logic_menuitem.Sensitive = logic_tbbutton.Sensitive = false;
 
-			if (playing == false && ((available & Game.Types.MemoryTrainer) == Game.Types.MemoryTrainer))
+			if (playing == false && ((available & GameTypes.MemoryTrainer) == GameTypes.MemoryTrainer))
 				memory_menuitem.Sensitive = memory_tbbutton.Sensitive = true;
 			else
 				memory_menuitem.Sensitive = memory_tbbutton.Sensitive = false;
 
-			if (playing == false && ((available & Game.Types.MathTrainer) == Game.Types.MathTrainer))
+			if (playing == false && ((available & GameTypes.MathTrainer) == GameTypes.MathTrainer))
 				calculation_menuitem.Sensitive = calculation_tbbutton.Sensitive = true;
 			else
 				calculation_menuitem.Sensitive = calculation_tbbutton.Sensitive = false;
 
-			if (playing == false && ((available & Game.Types.VerbalAnalogy) == Game.Types.VerbalAnalogy))
+			if (playing == false && ((available & GameTypes.VerbalAnalogy) == GameTypes.VerbalAnalogy))
 				verbal_menuitem.Sensitive = verbal_tbbutton.Sensitive = true;
 			else
 				verbal_menuitem.Sensitive = verbal_tbbutton.Sensitive = false;
 
-			if (playing == false && (available != Game.Types.None))
+			if (playing == false && (available != GameTypes.None))
 				allgames_menuitem.Sensitive = all_tbbutton.Sensitive = true;
 			else
 				allgames_menuitem.Sensitive = all_tbbutton.Sensitive = false;
 
-			pause_menuitem.Sensitive = finish_menuitem.Sensitive = playing;
+			finish_menuitem.Sensitive = playing;
 			newgame_menuitem.Sensitive = !playing;
 		}
 
@@ -407,7 +462,7 @@ namespace gbrainy.Clients.Classical
 			OnAnswerButtonClicked (this, EventArgs.Empty);
 			session.CurrentGame.AnswerEvent -= OnAnswerFromGame; // User can only answer once
 		}
-	
+
 		void OnMenuAbout (object sender, EventArgs args)
 		{
 			AboutDialog about = new AboutDialog ();
@@ -416,9 +471,9 @@ namespace gbrainy.Clients.Classical
 
 		void OnMenuHelp (object sender, EventArgs args)
 		{
-			Unix.ShowUri (null, "ghelp:gbrainy", 
+			Unix.ShowUri (null, "ghelp:gbrainy",
 				Gdk.EventHelper.GetTime (new Gdk.Event(IntPtr.Zero)));
-		}	
+		}
 
 		void OnAnswerButtonClicked (object sender, EventArgs args)
 		{
@@ -426,7 +481,7 @@ namespace gbrainy.Clients.Classical
 
 			if (session.CurrentGame == null)
 				return;
-	
+
 			if (session.ScoreGame (answer_entry.Text) == true)
 				answer = "<span color='#00A000'>" + Catalog.GetString ("Congratulations.") + "</span>";
 			else
@@ -441,17 +496,26 @@ namespace gbrainy.Clients.Classical
 			ActiveInputControls (true);
 			next_button.GrabFocus ();
 			drawing_area.QueueDraw ();
-		}		
+		}
 
 		void OnQuit (object sender, EventArgs args)
 		{
-			Quit ();	
-		}	
+#if GNOME
+			Quit ();
+#else
+			Gtk.Application.Quit ();
+#endif
+
+		}
 
 		void OnDeleteWindow (object sender, DeleteEventArgs args)
 		{
-			Quit ();	
-		}	
+#if GNOME
+			Quit ();
+#else
+			Gtk.Application.Quit ();
+#endif
+		}
 
 		void OnNextButtonClicked (object sender, EventArgs args)
 		{
@@ -476,7 +540,7 @@ namespace gbrainy.Clients.Classical
 		void OnNewGame (GameSession.Types type)
 		{
 			session.Type = type;
-			session.NewSession ();
+			session.New ();
 			GetNextGame ();
 			GameSensitiveUI ();
 			UpdateSolution (Catalog.GetString ("Once you have an answer type it in the \"Answer:\" entry box and press the \"OK\" button."));
@@ -504,21 +568,20 @@ namespace gbrainy.Clients.Classical
 
 			dialog = new PreferencesDialog (session.PlayerHistory);
 			if ((Gtk.ResponseType) dialog.Run () == ResponseType.Ok) {
-				session.Difficulty = (Game.Difficulty) Preferences.GetIntValue (Preferences.DifficultyKey);
+				session.Difficulty = (GameDifficulty) Preferences.GetIntValue (Preferences.DifficultyKey);
 			}
 			dialog.Destroy ();
 		}
 
 		void OnCustomGame (object sender, EventArgs args)
 		{
-			ResponseType rslt;
 			CustomGameDialog dialog;
 
 			dialog = new CustomGameDialog (session.GameManager);
-			rslt = (Gtk.ResponseType) dialog.Run ();
+			dialog.Run ();
 			dialog.Destroy ();
 
-			if (rslt == ResponseType.Ok && dialog.NumOfGames > 0)
+			if (dialog.SelectionDone == true)
 				OnNewGame (GameSession.Types.Custom);
 		}
 
@@ -542,8 +605,8 @@ namespace gbrainy.Clients.Classical
 
 		void OnEndGame (object sender, EventArgs args)
 		{
-			session.EndSession ();
-	
+			session.End ();
+
 			UpdateSolution (String.Empty);
 			UpdateQuestion (String.Empty);
 			UpdateStatusBar ();
@@ -607,12 +670,12 @@ namespace gbrainy.Clients.Classical
 			dialog = new PlayerHistoryDialog (session.PlayerHistory);
 			dialog.Run ();
 			dialog.Destroy ();
-		}	
+		}
 
 		private void AddIcon (IconFactory stock, string stockid, string resource)
 		{
 			Gtk.IconSet iconset = stock.Lookup (stockid);
-		
+
 			if (iconset != null)
 				return;
 
@@ -621,7 +684,7 @@ namespace gbrainy.Clients.Classical
 			IconSource source = new IconSource ();
 			source.Pixbuf = img;
 			iconset.AddSource (source);
-			stock.Add (stockid, iconset);		
+			stock.Add (stockid, iconset);
 		}
 
 		void OnFullscreen (object sender, EventArgs args)
@@ -643,14 +706,46 @@ namespace gbrainy.Clients.Classical
 			Process.Start ("http://live.gnome.org/gbrainy/Extending");
 		}
 
-		public static void Main (string [] args) 
+		public static void Main (string [] args)
 		{
 			try {
 				Unix.SetProcessName ("gbrainy");
-			} catch {}
+			} 
+			catch (Exception e)
+			{
+				Console.WriteLine ("gbrainy.Main. Could not set process name. Error {0}", e);
+			}
 
-			GtkClient gui = new GtkClient (args);
-			gui.Run ();	
+			DateTime start_time = DateTime.Now;
+
+			GtkClient app = new GtkClient ();
+			CommandLine.Version ();
+
+			CommandLine line = new CommandLine (args);
+			line.Parse ();
+
+			if (line.Continue == false)
+				return;
+#if !GNOME
+			Gtk.Application.Init ();
+#endif
+
+			app.Initialize ();
+			if (line.PlayList.Length > 0) {
+				app.Session.GameManager.PlayList = line.PlayList;
+				app.InitialSessionType = GameSession.Types.Custom;
+			}
+			app.Session.GameManager.RandomOrder = line.RandomOrder;
+			app.ProcessDefaults ();
+
+			TimeSpan span = DateTime.Now - start_time;
+			Console.WriteLine (Catalog.GetString ("Startup time {0}"), span);
+
+#if GNOME
+			app.Run ();
+#else
+			Gtk.Application.Run ();
+#endif
 		}
 	}
 }
