@@ -23,7 +23,6 @@ using Mono.Unix;
 using System.Timers;
 
 using gbrainy.Core.Views;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Core.Main
 {
@@ -55,8 +54,8 @@ namespace gbrainy.Core.Main
 			}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MemoryTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MemoryTrainer;}
 		}
 
 		public int TotalTime {
@@ -67,7 +66,7 @@ namespace gbrainy.Core.Main
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			if (Preferences.GetBoolValue (Preferences.MemQuestionWarnKey) == false || 
 				IsPreviewMode == true) {
@@ -215,6 +214,9 @@ namespace gbrainy.Core.Main
 			double width = 0.04, height = 0.6;
 			const double w = 0.003, h = 0.003;
 
+			gr.DrawTextCentered (x + (width / 2), y + height + 0.05, Catalog.GetString ("Time left"));
+			gr.Stroke ();
+
 			gr.Save ();
 			gr.Color = new Color (0, 0, 0);	
 			gr.MoveTo (x, y);
