@@ -129,8 +129,9 @@ namespace gbrainy.Core.Main
 				properties.WriteXml (writer);
 				writer.Close ();
 			}		
-			catch (Exception)
+			catch (Exception e)
 			{
+				Console.WriteLine ("Preferences.Save. Could not save file {0}. Error {1}", file, e);
 			}
 		}
 	
@@ -154,11 +155,12 @@ namespace gbrainy.Core.Main
 			properties [key] = value.ToString ();
 		}
 
-		static void LoadDefaultValues ()
+		public static void LoadDefaultValues ()
 		{
+			properties.Clear ();
 			properties.Add (MemQuestionWarnKey, true.ToString ());
 			properties.Add (MemQuestionTimeKey, "4");
-			properties.Add (DifficultyKey, ((int)(Game.Difficulty.Medium)).ToString ());
+			properties.Add (DifficultyKey, ((int)(GameDifficulty.Medium)).ToString ());
 			properties.Add (MinPlayedGamesKey, "5");
 			properties.Add (MaxStoredGamesKey, "20");
 			properties.Add (ToolbarKey, true.ToString ());
@@ -169,14 +171,18 @@ namespace gbrainy.Core.Main
 		{
 			try {
 				LoadDefaultValues ();
+				
+				if (File.Exists (file) == false)
+					return;
+
 				XmlTextReader reader = new XmlTextReader (file);
 				properties.ReadXml (reader);
 				reader.Close ();
 			}
-			catch (Exception)
+			catch (Exception e)
 			{
+				Console.WriteLine ("Preferences.Load. Could not load file {0}. Error {1}", file, e);
 			}
 		}
-	
 	}
 }
