@@ -29,10 +29,6 @@ namespace gbrainy.Core.Main.Verbal
 	{
 		protected Analogy current;
 
-		public override string Name {
-			get { return Catalog.GetString ("Verbal analogies"); }
-		}
-
 		public override string Question {
 			get {
 				if (current == null)
@@ -51,96 +47,74 @@ namespace gbrainy.Core.Main.Verbal
 			}
 		}
 
-		public override bool IsPlayable {
-			get { return List.Count > 0;}
-		}
-
 		public override string Answer {
 			get {
-				if (current == null)
-					return string.Empty;
+				string str;
+				if (current == null || current.MultipleAnswers == false)
+					return base.Answer;
 
-				if (current.MultipleAnswers == true) 
-				{
-					string [] items;
-					string str = string.Empty;
-	
-					items = right_answer.Split (AnalogiesFactory.Separator);
+				str = String.Format (Catalog.GetString ("Possible correct answers are: {0}."), AnswerValue);
 
-					for (int i = 0 ; i < items.Length; i++)
-					{
-						str += items [i].Trim ();
-						if (i + 1 < items.Length) {
-							// Translators: this the separator used when concatenating multiple possible answers for verbal analogies
-							// For example: "Possible correct answers are: sleep, rest."
-							str += Catalog.GetString (", ");
-						}
-					}
-					str = String.Format (Catalog.GetString ("Possible correct answers are: {0}."), str);
+				if (String.IsNullOrEmpty (Rationale))
 					return str;
-				}
 
-				if (String.IsNullOrEmpty (current.rationale) == false)
-					return base.Answer + " " + current.rationale;
-
-				return base.Answer;
+				return str += " " + Rationale;
 			}
 		}
 
-		public override Types Type {
-			get { return Game.Types.VerbalAnalogy;}
+		public override string Rationale {
+			get {
+				if (current == null)
+					return string.Empty;
+				
+				return current.rationale;
+			}
 		}
 
-		public abstract ArrayListIndicesRandom Indices {
-			get;
-			set;
+		public override string AnswerValue {
+			get { 
+				if (current == null || current.MultipleAnswers == false)
+					return right_answer;
+
+				string [] items;
+				string str = string.Empty;
+
+				items = right_answer.Split (AnalogiesFactory.Separator);
+
+				for (int i = 0 ; i < items.Length; i++)
+				{
+					str += items [i].Trim ();
+					if (i + 1 < items.Length) {
+						// Translators: this the separator used when concatenating multiple possible answers for verbal analogies
+						// For example: "Possible correct answers are: sleep, rest."
+						str += Catalog.GetString (", ");
+					}
+				}
+				return str;
+			}
 		}
 
-		public abstract int CurrentIndex {
-			get;
-			set;
-		}
-
-		// Returns true when this game manager has no more games to server
-		public bool IsExhausted {
-			get { return CurrentIndex + 1 >= List.Count;}
+		public override GameTypes Type {
+			get { return GameTypes.VerbalAnalogy;}
 		}
 
 		public abstract Dictionary <int, Analogy> List {
 			get;
 		}
 
+		public override int Variants {
+			get { return List.Count;}
+		}
+
 		public Analogy GetNext ()
 		{
-			int idx;
 			Analogy analogy; // Holds a deep copy
 			Analogy analogy_ref; // Holds reference to the object
 			ArrayListIndicesRandom indices = null;
 			int new_right = 0;
 			bool localized = true;
 
-			if (List.Count == 0)
-				return null;
-
-			if (Indices == null || CurrentIndex + 1 >= List.Count) {
-				Indices = new ArrayListIndicesRandom (List.Count);
-				Indices.Initialize ();
-			}
-			else
-				CurrentIndex++;
-
-			idx = Indices [CurrentIndex];
-		
-			try
-			{
-				List.TryGetValue (idx, out analogy_ref);
-			}
-
-			catch (KeyNotFoundException)
-			{
-				return null;
-			}
-
+			List.TryGetValue (Variant, out analogy_ref);
 			analogy = analogy_ref.Copy ();
 
 			if (analogy.answers != null) { // Randomize answers order
@@ -180,7 +154,7 @@ namespace gbrainy.Core.Main.Verbal
 			} else {
 
 				// Get analogy again
-				List.TryGetValue (idx, out analogy_ref);
+				List.TryGetValue (Variant, out analogy_ref);
 				analogy = analogy_ref.Copy ();
 
 				if (analogy.answers != null) { // Randomize answers order
@@ -198,20 +172,5 @@ namespace gbrainy.Core.Main.Verbal
 
 			return analogy;
 		}
-
-		public override bool CheckAnswer (string answer)
-		{
-			string [] items = right_answer.Split (AnalogiesFactory.Separator);
-
-			foreach (string ans in items)
-			{
-				string str = ans.Trim ();
-
-				if (String.Compare (str, answer, true) == 0)
-					return true;
-			}
-
-			return base.CheckAnswer (answer);
-		}
 	}
 }
