@@ -19,9 +19,6 @@
 
 using System;
 
-using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
-
 namespace gbrainy.Core.Toolkit
 {
 	public class SeletectedEventArgs: EventArgs
