@@ -17,12 +17,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Calculation
 {
@@ -45,29 +42,29 @@ namespace gbrainy.Games.Calculation
 			get {return Catalog.GetString ("Arithmetical");}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MathTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MathTrainer;}
 		}
 
 		public override string Question {
 			get {return Catalog.GetString ("What is the result of the arithmetical operation?");} 
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			int result = 0, operations = 0;
 			operation = (Operation) random.Next ((int) Operation.LastOperation);
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				max_operations = 2;
 				max_operand = 50;
 				break;
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				max_operations = 3;
 				max_operand = 100;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				max_operations = 5;
 				max_operand = 500;
 				break;
