@@ -18,11 +18,9 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Calculation
@@ -40,8 +38,8 @@ namespace gbrainy.Games.Calculation
 			get {return Catalog.GetString ("Average");}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MathTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MathTrainer;}
 		}
 
 		public override string Question {
@@ -62,34 +60,31 @@ namespace gbrainy.Games.Calculation
 			get { return Catalog.GetString ("The average of a list of numbers is the sum of all of the numbers divided by the number of items in the list.");}
 		}
 
-		public override string Answer {
+		public override string Rationale {
 			get { 
-				string answer = base.Answer + " ";
-
-				answer += String.Format (Catalog.GetString ("The result of the operation is {0:##0.###}."), 
-					correct);
-				return answer;
+				return String.Format (Catalog.GetString ("The result of the operation is {0:##0.###}."), 
+					correct);				
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			bool duplicated;
 			int nums, options_next, dist, num_size, which = 0;
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				nums = 3;
 				dist = nums * 3;
 				num_size = 50;
 				break;
 			default:
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				nums = 5;
 				dist = nums * 3;
 				num_size = 150;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				nums = 7;
 				dist = nums * 3;
 				num_size = 500;
