@@ -18,11 +18,9 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Calculation
@@ -39,30 +37,30 @@ namespace gbrainy.Games.Calculation
 			get {return Catalog.GetString ("Greatest divisor");}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MathTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MathTrainer;}
 		}
 
 		public override string Question {
 			get {return Catalog.GetString ("Which of the possible divisors is the greatest that divides all numbers?");} 
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{	
 			bool found;
 			int n, m;
 			int []mult = new int [3];
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				max_num = 999;
 				num_answ_ques = 3;
 				break;
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				max_num = 999;
 				num_answ_ques = 4;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				max_num = 9999;
 				num_answ_ques = 4;
 				break;
