@@ -19,36 +19,46 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Calculation
 {
 	public class CalculationOperator : Game
 	{
 		private double number_a, number_b, number_c, total;
-		private char[] opers = {'*', '+', '-', '/'};
+		private readonly char[] opers = {'*', '+', '-', '/'};
 		private char oper1, oper2;
 
 		public override string Name {
-			get {return Catalog.GetString ("Operator");}
+			get {return Catalog.GetString ("Operators");}
 		}
 
 		public override string Tip {
 			get {return String.Format( Catalog.GetString ("The first operator is {0}."), oper1);}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MathTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MathTrainer;}
 		}
 
 		public override string Question {
 			get {return String.Format (Catalog.GetString ("Which operators make {0}, {1}, and {2} equal {3}? Answer using '+-/*'."), number_a, number_b, number_c, total);}
 		}
 
+		public override string AnswerCheckExpression {
+			get { return "[+*-/]"; }
+		}
+
+		public override GameAnswerCheckAttributes CheckAttributes {
+			get { return GameAnswerCheckAttributes.Trim | GameAnswerCheckAttributes.MatchAll; }
+		}
+
+		public override string AnswerValue {
+			get { return String.Format (Catalog.GetString ("{0} and {1}"), oper1, oper2); }
+		}
+
 		private double ProcessOperation (double total, double number, char op)
 		{
 			switch (op) {
@@ -64,7 +74,7 @@ namespace gbrainy.Games.Calculation
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			while (true)
 			{
@@ -106,7 +116,7 @@ namespace gbrainy.Games.Calculation
 					break;
 			}
 
-			right_answer = String.Format (Catalog.GetString ("{0} and {1}"), oper1, oper2);
+			right_answer = String.Format ("{0} | {1}", oper1, oper2);
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -133,40 +143,5 @@ namespace gbrainy.Games.Calculation
 			gr.ShowPangoText ((DrawAnswer == true) ?  oper2.ToString () : "?");
 
 		}
-
-		private bool IndexOf (char c, char [] chars)
-		{
-			for (int i = 0; i < chars.Length; i++)
-				if (c == chars [i]) return true;
-
-			return false;
-		}
-
-		public override bool CheckAnswer (string answer)
-		{
-			char op1 = '\0', op2 = '\0';
-			int c = 0;
-
-			for (c = 0; c < answer.Length; c++)
-			{
-				if (IndexOf (answer[c], opers)) {
-					op1 = answer[c];
-					break;
-				}
-			}
-
-			for (c++; c < answer.Length; c++)
-			{
-				if (IndexOf (answer[c], opers)) {
-					op2 = answer[c];
-					break;
-				}
-			}
-
-			if (oper1 == op1 && oper2 == op2)
-				return true;
-
-			return false;
-		}
 	}
 }
