@@ -18,11 +18,9 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Calculation
@@ -155,8 +153,8 @@ namespace gbrainy.Games.Calculation
 			get {return Catalog.GetString ("Primes");}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MathTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MathTrainer;}
 		}
 
 		public override string Question {
@@ -167,23 +165,23 @@ namespace gbrainy.Games.Calculation
 			get { return Catalog.GetString ("If the sum of all digits in a given number is divisible by 3, then so is the number. For example 15 = 1 + 5 = 6, which is divisible by 3.");}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{	
 			int answer;
 			int max_primeidx;
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				max = 500;
 				div3 = true;
 				max_primeidx = 94;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				max = 10000;
 				div3 = false;
 				max_primeidx = total_primes;
 				break;		
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 			default:
 				max = 1000;
 				div3 = true;
