@@ -18,11 +18,9 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Calculation
@@ -39,8 +37,8 @@ namespace gbrainy.Games.Calculation
 			get {return Catalog.GetString ("Proportions");}
 		}
 
-		public override Types Type {
-			get { return Game.Types.MathTrainer;}
+		public override GameTypes Type {
+			get { return GameTypes.MathTrainer;}
 		}
 
 		public override string Question {
@@ -50,19 +48,19 @@ namespace gbrainy.Games.Calculation
 					percentage, num, den, GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			int options_next, random_max, which = 0;
 		
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				random_max = 30;
 				break;
 			default:
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				random_max = 50;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				random_max = 80;
 				break;
 			}
