@@ -18,9 +18,6 @@
  */
 
 using System;
-using System.Collections;
-using System.Collections.Generic;
-using Mono.Unix;
 
 using gbrainy.Games.Calculation;
 using gbrainy.Games.Logic;
@@ -36,7 +33,7 @@ namespace gbrainy.Games
 			typeof (PuzzleSquares),
 			typeof (PuzzleFigures),
 			typeof (PuzzleMoveFigure),
-			typeof (PuzzleCirclesRectangle),
+			typeof (PuzzleCirclesSquare),
 			typeof (PuzzlePencil),
 			typeof (PuzzleTriangles),
 			typeof (PuzzleCoverPercentage),
@@ -76,6 +73,7 @@ namespace gbrainy.Games
 			typeof (Puzzle3DCube),
 			typeof (PuzzlePredicateLogic),
 			typeof (PuzzleDice),
+			typeof (PuzzleTrains),
 		};
 
 		static Type[] CalculationTrainersInternal = new Type[] 
