@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -42,18 +40,18 @@ namespace gbrainy.Games.Logic
 			get { return Catalog.GetString ("A cube is a regular solid object having six congruent square faces.");}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			int ans, max_random;
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				max_random = 1;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				max_random = 5;
 				break;
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 			default:
 				max_random = 3;
 				break;		
