@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -47,11 +45,11 @@ namespace gbrainy.Games.Logic
 			get {return question; }
 		}
 
-		public override string Answer {
-			get { return base.Answer + " " + answer;}
+		public override string Rationale {
+			get { return answer;}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			int ans, var, total;
 
