@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -74,11 +72,11 @@ namespace gbrainy.Games.Logic
 			get { return problems[problem].question;}
 		}
 
-		public override string Answer {
-			get { return base.Answer + " " + problems[problem].rationale; }
+		public override string Rationale {
+			get { return problems[problem].rationale; }
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			problem = random.Next (problems.Length);
 			right_answer = problems[problem].answer;
@@ -89,10 +87,10 @@ namespace gbrainy.Games.Logic
 			base.Draw (gr, area_width, area_height, rtl);
 			
 			if (problems[problem].single)
-				gr.DrawImageFromAssembly ("dice.svg", 0.3, 0.3, 0.4, 0.8);
+				gr.DrawImageFromAssembly ("dice.svg", 0.3, 0.3, 0.4, 0.4);
 			else {
-				gr.DrawImageFromAssembly ("dice.svg", 0.1, 0.3, 0.4, 0.8);
-				gr.DrawImageFromAssembly ("dice.svg", 0.5, 0.3, 0.4, 0.8);
+				gr.DrawImageFromAssembly ("dice.svg", 0.1, 0.3, 0.4, 0.4);
+				gr.DrawImageFromAssembly ("dice.svg", 0.5, 0.3, 0.4, 0.4);
 			}
 		}
 
