@@ -18,11 +18,9 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -51,9 +49,9 @@ namespace gbrainy.Games.Logic
 			get {return Catalog.GetString ("In the last figure, in how many regions is the circle divided into when all dots are connected?");} 
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
-			if (CurrentDifficulty==Difficulty.Easy)
+			if (CurrentDifficulty==GameDifficulty.Easy)
 				dots = 5;
 			else
 				dots = 5 + random.Next (2);
