@@ -18,12 +18,10 @@
  */
 
 using System;
-using Cairo;
 using System.Text;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Logic
@@ -48,17 +46,13 @@ namespace gbrainy.Games.Logic
 			get {return Catalog.GetString ("What is the next logical sequence of objects in the last column? See below the convention when giving the answer.");} 
 		}
 
-		public override string Answer {
-			get { 
-				string answer = base.Answer + " ";
-
-				answer += Catalog.GetString ("It is the only combination that you can build with the given elements without repeating them.");
-
-				return answer;
+		public override string Rationale {
+			get {
+				return Catalog.GetString ("It is the only combination that you can build with the given elements without repeating them.");
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			random_indices = new ArrayListIndicesRandom (6);
 			random_indices.Initialize ();
@@ -82,7 +76,7 @@ namespace gbrainy.Games.Logic
 			{
 				e.Context.MoveTo (0, 0.05);
 				e.Context.ShowPangoText (String.Format (Catalog.GetString ("{0} ->"), GetPossibleAnswer (0)));
-				e.Context.DrawDiamond (0.1, 0, 0.1);
+				e.Context.DrawPentagon (0.1, 0, 0.1);
 				e.Context.Stroke ();
 			};
 
@@ -128,7 +122,7 @@ namespace gbrainy.Games.Logic
 					switch (figures[(n * 6) + element])
 					{
 						case 0:
-							gr.DrawDiamond (x, y, 0.1);
+							gr.DrawPentagon (x, y, 0.1);
 							break;
 						case 1:
 							gr.Arc (x + 0.05, y + 0.05, 0.05, 0, 2 * Math.PI);	
@@ -166,14 +160,8 @@ namespace gbrainy.Games.Logic
 
 			y += 0.16;
 			gr.MoveTo (x, y);		
-			gr.ShowPangoText (String.Format (Catalog.GetString ("E.g: {0}{1}{2} (diamond, triangle, circle)"),
+			gr.ShowPangoText (String.Format (Catalog.GetString ("E.g: {0}{1}{2} (pentagon, triangle, circle)"),
 				GetPossibleAnswer (0), GetPossibleAnswer (2), GetPossibleAnswer (1)));
 		}
-
-		public override bool CheckAnswer (string answer)
-		{
-			answer = TrimAnswer (answer);
-			return base.CheckAnswer (answer);
-		}
 	}
 }
