@@ -22,7 +22,6 @@ using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Logic
@@ -73,15 +72,13 @@ namespace gbrainy.Games.Logic
 			get { return Catalog.GetString ("Each slice is related to the opposite one.");}
 		}
 
-		public override string Answer {
-			get { 
-				string answer = base.Answer + " ";
-				answer += String.Format (Catalog.GetString ("All numbers of each slice, when added to the ones of the opposite slice, add always {0}."), sum_offset + 8);
-				return answer;
+		public override string Rationale {
+			get {
+				return String.Format (Catalog.GetString ("All numbers of each slice, when added to the ones of the opposite slice, add always {0}."), sum_offset + 8);
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			sum_offset = random.Next (3);
 			random_indices = new ArrayListIndicesRandom (slices.Length / items_per_slice);
