@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -47,17 +45,17 @@ namespace gbrainy.Games.Logic
 			get {return question; }
 		}
 
-		public override string Answer {
+		public override string Rationale {
 			get {
-
-				if (String.IsNullOrEmpty (answer) == true)
-					return base.Answer;
-
-				return base.Answer + " " + answer;
+				return answer;
 			}
 		}
 
-		public override void Initialize ()
+		public override string AnswerCheckExpression {
+			get { return "[0-9]+";}
+		}
+
+		protected override void Initialize ()
 		{
 			int ans;
 
@@ -126,18 +124,5 @@ namespace gbrainy.Games.Logic
 		{
 			base.Draw (gr, area_width, area_height, rtl);
 		}
-
-		public override bool CheckAnswer (string answer)
-		{	
-			if (gametype == GameType.Water) {
-				if (String.Compare (answer, right_answer + "%", true) == 0) 
-					return true;
-			}
-
-			if (String.Compare (answer, right_answer, true) == 0) 
-				return true;
-
-			return false;
-		}
 	}
 }
