@@ -19,11 +19,9 @@
 
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Logic
@@ -79,7 +77,7 @@ namespace gbrainy.Games.Logic
 				Catalog.GetString ("None of the other options"),
 				3),
 
-			new Predicate (String.Format (Catalog.GetString ("If you whistle if you are happy and you only smile when you whistle. Which of the following sentences is correct? Answer {0}, {1}, {2} or {3}."),
+			new Predicate (String.Format (Catalog.GetString ("If you whistle if you are happy and you always smile when you whistle, which of the following sentences is correct? Answer {0}, {1}, {2} or {3}."),
 				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
 				Catalog.GetString ("You smile if you are happy"),
 				Catalog.GetString ("You are only happy if you whistle"),
@@ -96,14 +94,7 @@ namespace gbrainy.Games.Logic
 			get {return predicates[question].question;} 
 		}
 
-		public override string Answer {
-			get { 
-				string answer = base.Answer + " ";
-				return answer;
-			}
-		}
-
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			int answers;
 			int correct_answer;
