@@ -18,11 +18,9 @@
  */
 
 using System;
-using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -53,15 +51,13 @@ namespace gbrainy.Games.Logic
 					GetPossibleAnswer (5));}
 		}
 
-		public override string Answer {
-			get { 
-				string answer = base.Answer + " ";
-				answer += Catalog.GetString ("It is the only figure with all lines of equal length.");
-				return answer;
+		public override string Rationale {
+			get {
+				return Catalog.GetString ("It is the only figure with all lines of equal length.");
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			random_indices = new ArrayListIndicesRandom ((int) Figures.Last);
 			random_indices.Initialize ();
