@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Logic
@@ -43,15 +41,13 @@ namespace gbrainy.Games.Logic
 				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2));}
 		}
 
-		public override string Answer {
-			get { 
-				string answer = base.Answer + " ";
-				answer += Catalog.GetString ("It is the figure that completes all possible combinations with four blocks without taking into account rotations.");
-				return answer;
+		public override string Rationale {
+			get {
+				return Catalog.GetString ("It is the figure that completes all possible combinations with four blocks without taking into account rotations.");
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			random_indices_questions = new ArrayListIndicesRandom (4);
 			random_indices_questions.Initialize ();
