@@ -22,7 +22,6 @@ using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Memory
 {
@@ -55,16 +54,16 @@ namespace gbrainy.Games.Memory
 			}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				maxdotscolor = 2;
 				break;
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				maxdotscolor = 5;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				maxdotscolor = 8;
 				break;
 			}
