@@ -22,7 +22,6 @@ using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 using gbrainy.Core.Toolkit;
 
 namespace gbrainy.Games.Memory
@@ -61,21 +60,21 @@ namespace gbrainy.Games.Memory
 				return Catalog.GetString ("In which cell is the other figure like the one shown below? Answer the cell number." );}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			int fig1, fig2;
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				figures_active = 4;
 				rows = columns = 3;
 				break;
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				figures_active = 6;
 				rows = 3;
 				columns = 4;			
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				figures_active = 8;
 				columns = rows = 4;
 				break;
