@@ -22,7 +22,6 @@ using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Memory
 {
@@ -40,8 +39,8 @@ namespace gbrainy.Games.Memory
 		static internal class FigureType
 		{
 			internal const int Triangle = 0;
-			internal const int Rectangle = 1;
-			internal const int Diamond = 2;
+			internal const int Square = 1;
+			internal const int Pentagon = 2;
 			internal const int Circle = 3;
 			internal const int Total = Circle + 1;
 
@@ -50,10 +49,10 @@ namespace gbrainy.Games.Memory
 				switch (type) {
 				case Triangle:
 					return Catalog.GetString ("Triangle");
-				case Rectangle:
-					return Catalog.GetString ("Rectangle");
-				case Diamond:
-					return Catalog.GetString ("Diamond");
+				case Square:
+					return Catalog.GetString ("Square");
+				case Pentagon:
+					return Catalog.GetString ("Pentagon");
 				case Circle:
 					return Catalog.GetString ("Circle");
 				default:
@@ -67,25 +66,25 @@ namespace gbrainy.Games.Memory
 		}
 
 		public override string MemoryQuestion {
-			get {return Catalog.GetString ("The list below enumerates the figures shown in the previous image except for one. Which is the missing figure? Possible answers are triangle, rectangle, diamond and circle." );}
+			get {return Catalog.GetString ("The list below enumerates the figures shown in the previous image except for one. Which is the missing figure? Possible answers are triangle, square, pentagon and circle." );}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
 			ArrayListIndicesRandom figures_random;
 			int pos = 0;
 
 			switch (CurrentDifficulty) {
-			case Difficulty.Easy:
+			case GameDifficulty.Easy:
 				figures_active = 4;
 				rows = columns = 2;
 				break;
-			case Difficulty.Medium:
+			case GameDifficulty.Medium:
 				figures_active = 6;
 				rows = 2;
 				columns = 3;
 				break;
-			case Difficulty.Master:
+			case GameDifficulty.Master:
 				figures_active = 9;
 				columns = rows = 3;
 				break;
@@ -186,12 +185,12 @@ namespace gbrainy.Games.Memory
 			case FigureType.Triangle:
 				gr.DrawEquilateralTriangle (x + space_x, y + space_y, figure_size);
 				break;
-			case FigureType.Rectangle:
+			case FigureType.Square:
 				gr.Rectangle (x + space_x, y + space_y, figure_size, figure_size);
 				gr.Stroke ();
 				break;
-			case FigureType.Diamond:
-				gr.DrawDiamond (x + space_x, y + space_y, figure_size);
+			case FigureType.Pentagon:
+				gr.DrawPentagon (x + space_x, y + space_y, figure_size);
 				break;
 			case FigureType.Circle:
 				gr.Arc (x + space_x + figure_size / 2, y + space_y + figure_size / 2, figure_size / 2, 0, 2 * Math.PI);
